#
# spec file for package python-oslo.concurrency
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-oslo.concurrency
Version:        6.1.0
Release:        1.2
Summary:        OpenStack oslo.concurrency library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/oslo.concurrency
Source0:        https://files.pythonhosted.org/packages/source/o/oslo.concurrency/oslo.concurrency-6.1.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-eventlet
BuildRequires:  python3-fasteners >= 0.7.0
BuildRequires:  python3-fixtures
BuildRequires:  python3-oslo.config >= 5.2.0
BuildRequires:  python3-oslo.i18n >= 3.15.3
BuildRequires:  python3-oslo.utils >= 3.33.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-stestr
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
The oslo.concurrency library has utilities for safely running multi-thread,
multi-process applications using locking mechanisms and for running
external processes.

%package -n python3-oslo.concurrency
Summary:        OpenStack oslo.concurrency library
Requires:       python3-fasteners >= 0.7.0
Requires:       python3-oslo.config >= 5.2.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.utils >= 3.33.0
%if 0%{?suse_version}
Obsoletes:      python2-oslo.concurrency < 4.0.0
%endif

%description -n python3-oslo.concurrency
The oslo.concurrency library has utilities for safely running multi-thread,
multi-process applications using locking mechanisms and for running
external processes.

This package contains the Python 3.x module.

%package -n python-oslo.concurrency-doc
Summary:        Documentation for OpenStack concurrency library
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-sphinxcontrib-apidoc

%description -n python-oslo.concurrency-doc
The oslo.concurrency library has utilities for safely running multi-thread,
multi-process applications using locking mechanisms and for running
external processes.
This package contains the documentation.

%prep
%autosetup -p1 -n oslo.concurrency-6.1.0
%py_req_cleanup

%build
%{py3_build}

# generate html docs
PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
env TEST_EVENTLET=0 %{openstack_stestr_run}
env TEST_EVENTLET=1 %{openstack_stestr_run}

%files -n python3-oslo.concurrency
%license LICENSE
%doc README.rst ChangeLog
%{_bindir}/lockutils-wrapper
%{python3_sitelib}/oslo_concurrency
%{python3_sitelib}/*.egg-info

%files -n python-oslo.concurrency-doc
%license LICENSE
%doc doc/build/html

%changelog
* Mon Sep  2 2024 cloud-devel@suse.de
- update to version 6.1.0
  - Update master for stable/2024.1
  - Remove old excludes
  - reno: Update master for unmaintained/victoria
* Sun Mar 24 2024 cloud-devel@suse.de
- update to version 6.0.0
  - pre-commit: Integrate bandit
  - Deprecate Windows support
  - Display coverage report
  - Drop fallback to DEFAULT section
  - pre-commit: Bump versions
  - Update python classifier in setup.cfg
  - Update master for stable/2023.2
  - Bump hacking
  - Fix wrong stacklevel
* Thu Jan  4 2024 cloud-devel@suse.de
- update to version 5.2.0
  - Update master for stable/2023.1
  - Imported Translations from Zanata
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
  - Bump bandit
  - Moves supported python runtimes from version 3.8 to 3.10
* Wed May  3 2023 cloud-devel@suse.de
- update to version 5.1.1
  - Fix issues related to tox4
  - Cleanup py27 support
  - Imported Translations from Zanata
* Mon Mar  6 2023 Dirk Müller <dmueller@suse.com>
- avoid eventlet lockup
* Sat Oct  1 2022 cloud-devel@suse.de
- update to version 5.0.1
  - Log when waiting to acquire lock
  - Ignore coverage result files
  - Fix formatting of release list
  - Drop python3.6/3.7 support in testing runtime
  - Fix fair internal lock used from eventlet.spawn_n
  - Prove that spawn_n with fair lock is broken
  - Imported Translations from Zanata
* Tue May 24 2022 cloud-devel@suse.de
- update to version 4.5.1
  - Add support for non-blocking locks
  - Use TOX_CONSTRAINTS_FILE
  - Dropping lower constraints testing
  - Remove references to 'sys.version_info'
  - Update CI to use unversioned jobs template
  - Add Python3 wallaby unit tests
  - Adding pre-commit
  - Fix RequiredOptError when missing lock_path
  - Remove unnecessary unicode prefixes
  - Monkey patch original current_thread _active in processutils
  - Use py3 as the default runtime for tox
  - Update master for stable/victoria
  - Allow python_exec kwarg to be None
  - Move flake8 as a pre-commit local target.
  - Add Python3 yoga unit tests
  - setup.cfg: Replace dashes with underscores
  - Remove lower-constraints remnants
  - Update python testing classifier
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 4.3.0
  - Don't warn on lock removal if file doesn't exist
  - Bump default tox env from py37 to py38
  - Add support for timeout to processutils.execute
  - Monkey patch original current_thread _active
  - Stop to use the __future__ module.
  - Remove babel.cfg etc
  - Switch to newer openstackdocstheme and reno versions
  - Imported Translations from Zanata
  - Update master for stable/ussuri
  - Align contributing doc with oslo's policy
  - Remove six usage
  - Fix pygments style
  - Update lower-constraints versions
  - Fix hacking min version to 3.0.1
  - Bump bandit version
  - Add py38 package metadata
  - Add Python3 victoria unit tests
  - Add release notes links to doc index
  - Remove the unused coding style modules
* Tue May 12 2020 cloud-devel@suse.de
- update to version 4.0.2
  - Spiff up docs for *_with_prefix
  - Blacklist sphinx 2.1.0 (autodoc bug)
  - tox: Keeping going with docs
  - Stop to build universal wheel
  - Update the constraints url
  - tox: Trivial cleanup
  - Update master for stable/train
  - ignore reno builds artifacts
  - Drop python 2.7 support and testing
  - Document management and history of lock files
  - Update hacking for Python3
  - Switch to Ussuri jobs
  - Add lock_with_prefix convenience utility
  - Fix remove_lock test
  - trivial: Cleanup tox.ini
  - remove outdated header
  - Use unittest.mock instead of third party mock
  - Stop configuring install_command in tox.
  - Some test cleanup
  - Bump the openstackdocstheme extension to 1.20
* Mon Mar 23 2020 Dirk Mueller <dmueller@suse.com>
- add obsoletes
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 3.30.0
  - Update master for stable/stein
  - Replace git.openstack.org URLs with opendev.org URLs
  - Dropping the py35 testing
  - Add Python 3 Train unit tests
  - Cap Bandit below 1.6.0 and update Sphinx requirement
  - OpenDev Migration Patch
  - Follow the new PTI for document build
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 3.29.1
  - Switch to stestr
  - Imported Translations from Zanata
  - Update mailinglist from dev to discuss
  - Remove PyPI downloads
  - Change python3.5 job to python3.7 job on Stein+
  - import zuul job settings from project-config
  - ignore warning from bandit for using shell=
  - Always build universal wheels
  - Update reno for stable/rocky
  - Reorganize that 'Release Notes' in README
  - Don't quote {posargs} in tox.ini
  - add python 3.6 unit test job
  - add lib-forward-testing-python3 test job
  - Remove stale pip-missing-reqs tox test
  - Trivial: Update pypi url to new url
  - Add support for fair locks
  - fix tox python3 overrides
  - Update hacking version
  - Clean up .gitignore references to personal tools
  - Stop using setup.py build_sphinx
  - Add release notes link to README
  - add python 3.7 unit test job
  - Use templates for cover and lower-constraints
* Sat Sep  1 2018 cloud-devel@suse.de
- update to version 3.27.0
  - set default python to python3
  - Update doc links in CONTRIBUTING.rst and README.rst
  - Mask passwords only when command execution fails
  - Update reno for stable/queens
  - fix lower constraints and uncap eventlet
  - Imported Translations from Zanata
  - Switch pep8 job to python 3
  - Updated from global requirements
  - add lower-constraints job
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Tue Jan 30 2018 cloud-devel@suse.de
- update to version 3.25.0
  - Add python_exec kwarg to processutils.execute()
  - Updated from global requirements
  - add bandit to pep8 job
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 3.24.0
  - Imported Translations from Zanata
  - Remove setting of version/release from releasenotes
  - Remove -U from pip install
  - Updated from global requirements
  - Avoid tox_install.sh for constraints support
* Fri Nov 24 2017 cloud-devel@suse.de
- update to version 3.23.0
  - Add debug log to indicate when external lock is taken
  - Update reno for stable/pike
  - Minor correction to docstrings
  - Windows: ensure exec calls don't block other greenthreads
  - Updated from global requirements
* Thu Sep 28 2017 cloud-devel@suse.de
- update to version 3.21.1
  - Update .gitreview for stable/pike
  - Windows: ensure exec calls don't block other greenthreads
  - Updated from global requirements
  - Update UPPER_CONSTRAINTS_FILE for stable/pike
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 3.21.0
  - Imported Translations from Zanata
  - Remove log translations
  - turn on warning-is-error for sphinx
  - Check reStructuredText documents for common style issues
  - Using fixtures.MockPatch instead of mockpatch.Patch
  - [Fix gate]Update test requirement
  - Update URLs in documents according to document migration
  - Remove support for py34
  - rearrange existing documentation to follow the new layout standard
  - pbr.version.VersionInfo needs package name (oslo.xyz and not oslo_xyz)
  - Update reno for stable/ocata
  - Check for SubprocessError by name on Python 3.x
  - Updated from global requirements
  - switch from oslosphinx to openstackdocstheme
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 3.18.0:
  - [TrivialFix] Replace 'assertTrue(a in b)' with 'assertIn(a, b)'
  - Update reno for stable/newton
  - Automatically convert process_input to bytes
  - Imported Translations from Zanata
  - Change assertTrue(isinstance()) by optimal assert
  - Updated from global requirements
  - Add Constraints support
  - Remove unnecessary requirements
  - Show team and repo badges on README
  - Changed the home-page link
  - Enable release notes translation
  - Ignore prlimit argument on Windows
* Tue Oct  4 2016 dmueller@suse.com
- switch to stable/newton
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 3.14.0
  * Fix external lock tests on Windows
  * Updated from global requirements
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 3.13.0
  * Add Python 3.5 classifier and venv
  * Imported Translations from Zanata
  * Fix parameters of assertEqual are misplaced
  * Updated from global requirements
  * Add reno for releasenotes management
* Fri Jun  3 2016 tbechtold@suse.com
- update to 3.9.0:
  * Add doc/ to pep8 check
  * Remove unused import statement
  * Add timeout option to ssh_execute
  * Fix wrong import example in docstring
  * Trivial: ignore openstack/common in flake8 exclude list
  * Updated from global requirements
  * Imported Translations from Zanata
  * processutils: add support for missing process limits
  * Remove direct dependency on babel
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Add a few usage examples for lockutils
  * Revert "Use tempfile.tempdir for lock_path if OSLO_LOCK_PATH is not set"
  * Updated from global requirements
  * Use tempfile.tempdir for lock_path if OSLO_LOCK_PATH is not set
* Thu Jun  2 2016 tbechtold@suse.com
- use renderspec source service
- update spec from upstream
* Mon Apr  4 2016 tbechtold@suse.com
- update to 3.7.0:
  * Updated from global requirements
  * Update .gitreview for stable/mitaka
- Adjust Requires
* Wed Mar 16 2016 tbechtold@suse.com
- Add python-enum34 as BuildRequires to fix tests
* Mon Feb 29 2016 dmueller@suse.com
- update to 3.6.0:
  * Updated from global requirements
  * Update translation setup
  * Add prlimit parameter to execute()
  * Imported Translations from Zanata
  * Remove unnecessary package in setup.cfg
* Sun Feb 28 2016 dmueller@suse.com
- update to 3.2.0:
  * Updated from global requirements
  * Trival: Remove 'MANIFEST.in'
  * Add complementary remove lock with prefix function
  * Drop python 2.6 support
  * Updated from global requirements
  * Remove python 2.6 classifier
  * Use versionadded and versionchanged in doc
  * Updated from global requirements
  * Imported Translations from Zanata
  * Fix Tests to run under OSX
  * Fix coverage configuration and execution
  * Imported Translations from Zanata
  * Move 'history' -> release notes section
  * add auto-generated docs for config options
  * Change ignore-errors to ignore_errors
  * Updated from global requirements
  * Imported Translations from Zanata
  * Use int enumerations for log error constants
* Wed Sep  9 2015 tbechtold@suse.com
- update to 2.6.0:
  * Removes unused posix-ipc requirement
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Thu Aug 27 2015 tbechtold@suse.com
- update to 2.5.0:
  * Updated from global requirements
  * Updated from global requirements
  * Use oslo_utils reflection to get 'f' callable name
  * flake8 - remove unused rules
  * Imported Translations from Transifex
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file
- Add -doc package
* Mon Jul 20 2015 dmueller@suse.com
- update to 2.3.0:
  * Imported Translations from Transifex
  * Allow preexec_fn method for processutils.execute
  * Updated from global requirements
  * Use pypi name for requirements.txt
  * processutils: ensure on_completion callback is always called
  * Updated from global requirements
  * Remove redundant fileutils
  * Add tox target to find missing requirements
* Fri Jul  3 2015 dmueller@suse.com
- add missing dependency on fasteners
* Wed Jun 24 2015 tbechtold@suse.com
- update to 2.1.0:
  * Imported Translations from Transifex
  * Updated from global requirements
  * Updated from global requirements
  * Add 2 callbacks to processutils.execute()
  * Updated from global requirements
  * Fix LockFixture docstring
  * Updated from global requirements
  * Switch badges from 'pypip.in' to 'shields.io'
  * Updated from global requirements
  * Replace locks and replace with fasteners library provides ones
* Wed Jun 10 2015 tbechtold@suse.com
- update to 2.0.0:
  * Remove oslo namespace package
- enable testsuite
* Tue Jun  2 2015 tbechtold@suse.com
- update to 1.10.0:
  * Imported Translations from Transifex
  * Sync from oslo-incubator
  * Updated from global requirements
  * Advertise support for Python3.4 / Remove support for 3.3
  * Updated from global requirements
  * Imported Translations from Transifex
  * Remove run_cross_tests.sh
  * Updated from global requirements
  * Updated from global requirements
  * Add binary parameter to execute and ssh_execute
  * Port processutils to Python 3
  * Uncap library requirements for liberty
  * Move fixtures to test-requirements.txt
  * Fix test_as_root* tests to work when run as root
  * Add pypi download + version badges
  * Standardize setup.cfg summary for oslo libs
  * Imported Translations from Transifex
  * Updated from global requirements
  * Remove tools/run_cross_tests.sh from openstack-common.conf
* Mon Mar 30 2015 tbechtold@suse.com
- update to 1.8.0:
  * Switch to non-namespaced module imports
  * Remove py33 env from default tox list
  * Add lockutils.get_lock_path() function
* Tue Mar 10 2015 tbechtold@suse.com
- update to 1.7.0:
  * Imported Translations from Transifex
  * Updated from global requirements
- adjust Requires according to requirements.txt
* Tue Feb 24 2015 tbechtold@suse.com
- update to 1.6.0:
  * Updated from global requirements
  * processutils: execute(): fix option incompatibility
  * Ability to set working directory
  * Add eventlet test check to new tests __init__.py
  * Drop use of namespaced oslo.i18n
  * Updated from global requirements
  * Updated from global requirements
  * Update Oslo imports to remove namespace package
* Thu Jan 15 2015 tbechtold@suse.com
- update to 1.4.1:
  * Revert "Port processutils to Python 3"
* Wed Jan 14 2015 tbechtold@suse.com
- update to version 0.4.0:
  * Bump to hacking 0.10
  * Updated from global requirements
  * add watchdog module
  * Updated from global requirements
  * make time format for processutils match lockutils
  * Correct the translation domain for loading messages
  * Add a reader/writer lock
  * Don't use ConfigFilter for lockutils
  * Report import warnings where the import occurs
  * Port processutils to Python 3
  * Activate pep8 check that _ is imported
  * Drop requirements-py3.txt
  * Updated from global requirements
  * Clean up API documentation
  * Workflow documentation is now in infra-manual
  * Remove noqa from test files
  * test compatibility for old imports
  * Fix bug link in README.rst
- Adjust BuildRequires according to test-requirements.txt
* Wed Jan 14 2015 tbechtold@suse.com
- Add python_requires to _service
- Adjust Requires according to requirements.txt
* Tue Dec  9 2014 dmueller@suse.com
- update to 0.3.0:
  * Add external lock fixture
  * Add a TODO for retrying pull request #20
  * Allow the lock delay to be provided
  * Allow for providing a customized semaphore container
  * Move locale files to proper place
  * Flesh out the README
  * Move out of the oslo namespace package
  * Improve testing in py3 environment
  * Only modify autoindex.rst if it exists
  * Imported Translations from Transifex
  * lockutils-wrapper cleanup
  * Don't use variables that aren't initialized
* Sat Nov  1 2014 dmueller@suse.com
- Initial package
